spawn_on_each

Function spawn_on_each 

pub fn spawn_on_each<F>(future: impl Fn() -> F) -> Vec<JoinHandle<F::Output>>
where F: Future + Send + 'static, F::Output: Send + 'static,
Spawn a copy of a task on each local runtime.

Use this to place a server listener on each of your thread local threads.