Builder

Struct Builder 

pub struct Builder { /* private fields */ }
A setup builder for your level runtime.

See tokio::runtime::Builder for more detailed documentation. A level runtime is a collection of tokio current-thread runtimes.

Implementations

Source

impl Builder

pub fn build(&mut self) -> LevelRuntime

Build a new level runtime

pub fn worker_threads(&mut self, threads: usize) -> &mut Self

How many thread-local worker threads do you want?

pub fn thread_name_prefix(&mut self, name: impl Into<String>) -> &mut Self

Set a thread name prefix for level threads.

pub fn enable_all(&mut self) -> &mut Self

Do you want to use IO and time?

pub fn event_interval(&mut self, interval: u32) -> &mut Self

How frequently should you epoll? (Default is 61)

pub fn global_queue_interval(&mut self, interval: u32) -> &mut Self

How frequently should you check for off-runtime task submission? (Default is 31)

pub fn max_io_events_per_tick(&mut self, capacity: usize) -> &mut Self

How many file descriptors should you epoll at a time? (Default is 1024)

pub fn max_blocking_threads(&mut self, capacity: usize) -> &mut Self

How many blocking threads should each local runtime be able to create? (Devault is 512)

pub fn on_thread_park( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut Self

Notification of thread park

pub fn on_thread_unpark( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut Self

Notification of thread unpark