LevelRuntime

Struct LevelRuntime 

pub struct LevelRuntime { /* private fields */ }
A wrapper for a collection of tokio current-thread runtimes.

It offers a load leveling heuristic, but not work stealing.

Implementations

Source

impl LevelRuntime

pub fn set_default(&self)

Register this LevelRuntime as the default runtime for the static level_runtime::spawn* family functions.

pub fn handle(&self) -> LevelRuntimeHandle

Get a spawn handle for the runtime.

pub fn run(self)

Execute this runtime.

pub fn start(&self)

Start this runtime in the background.

pub fn run_with_termination( self, termination: impl Future<Output = ()> + Send + 'static, )

Execute this runtime. When termination completes, the backing executors will close.