pub fn spawn_on_each<F>(future: impl Fn() -> F) -> Vec<JoinHandle<F::Output>>Expand description
Spawn a copy of a task on each local runtime.
Use this to place a server listener on each of your thread local threads.
pub fn spawn_on_each<F>(future: impl Fn() -> F) -> Vec<JoinHandle<F::Output>>Spawn a copy of a task on each local runtime.
Use this to place a server listener on each of your thread local threads.